summaryrefslogtreecommitdiffstats
path: root/lib/kross/api/object.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kross/api/object.cpp')
-rw-r--r--lib/kross/api/object.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/kross/api/object.cpp b/lib/kross/api/object.cpp
index 43fa8b4b..a9599f6d 100644
--- a/lib/kross/api/object.cpp
+++ b/lib/kross/api/object.cpp
@@ -27,19 +27,19 @@
using namespace Kross::Api;
Object::Object()
- : KShared()
+ : TDEShared()
{
#ifdef KROSS_API_OBJECT_CTOR_DEBUG
- krossdebug( TQString("Kross::Api::Object::Constructor() name='%1' refcount='%2'").arg(m_name).arg(_KShared_count()) );
+ krossdebug( TQString("Kross::Api::Object::Constructor() name='%1' refcount='%2'").arg(m_name).arg(_TDEShared_count()) );
#endif
}
Object::~Object()
{
#ifdef KROSS_API_OBJECT_DTOR_DEBUG
- krossdebug( TQString("Kross::Api::Object::Destructor() name='%1' refcount='%2'").arg(m_name).arg(_KShared_count()) );
+ krossdebug( TQString("Kross::Api::Object::Destructor() name='%1' refcount='%2'").arg(m_name).arg(_TDEShared_count()) );
#endif
//removeAllChildren(); // not needed cause we use KShared to handle ref-couting and freeing.
}
const TQString Object::toString()
@@ -27,19 +27,19 @@
#endif
- //removeAllChildren(); // not needed cause we use KShared to handle ref-couting and freeing.
+ //removeAllChildren(); // not needed cause we use TDEShared to handle ref-couting and freeing.
}
const TQString Object::toString()